==> python_metrc-0.1.0.tar.gz: python_metrc-0.1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=6.0', 'hammock>=0.2.4', ]
setup_requirements = ['pytest-runner', ]
test_requirements = ['pytest', ]

setup(
    author="DigiThinkIT, Inc.",
    author_email='hello@digithinkit.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="A light Python wrapper around the METRC Web API",
    entry_points={
        'console_scripts': [
            'python_metrc=python_metrc.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='python_metrc',
    name='python_metrc',
    packages=find_packages(include=['python_metrc']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/DigiThinkIT/python-metrc',
    version='0.1.0',
    zip_safe=False,
)

==> python_metrc-0.1.1.tar.gz: python_metrc-0.1.1/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['hammock>=0.2.4', ]
setup_requirements = ['pytest-runner', ]
test_requirements = ['pytest', ]

setup(
    author="DigiThinkIT, Inc.",
    author_email='hello@digithinkit.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="A light Python wrapper around the METRC Web API",
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='python_metrc',
    name='python_metrc',
    packages=find_packages(include=['python_metrc']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/DigiThinkIT/python-metrc',
    version='0.1.1',
    zip_safe=False,
)
